*** Gender bias, citizen participation, and AI ***
*** Natalia Pecorari and Jose Cuesta, 2024 ***
** Using Latinobarometro 2023 **
* Preparing the variables *

clear all
gl root "C:\WBG\github\255\v1\DEC Reproducibility Verification - WB Group"
sysdir set PLUS "${root}\ado"
set varabbrev on
set more off
global 	datain = "${root}\DataIn"
global  dataout = "${root}\DataOut"
cd 	"$root"
    
use 	"$datain\\Latinobarometro_2023_Eng_Stata_v1_0.dta",clear

********************************************************
*A. Demographic and socio-economic indicators
rename edad age

egen age_std = std(age) 

*1=male; 0=female
clonevar male = sexo 
recode male (2=0) 

label define male_label 0 "0" 1 "1"
label values male male_label

rename idenpa country

* Education all levels (Illiterate, Incomplete basic education, Complete basic education, Incomplete secondary education, Complete secondary education, Incomplete Universitary education, Complete Universitary education)
clonevar education = REEEDUC_1
replace education=. if REEEDUC_1 <= 0 

* Education dummmies
gen education_cat = education
tabulate education_cat, generate(edu_cat)
drop edu_cat1
list edu_cat2 edu_cat3 edu_cat4 edu_cat5 edu_cat6 edu_cat7

*Social class all categories (from highest to lowest: upper class, upper middle class, middle class, lower middle class and lower class)
clonevar social_class = S2
replace social_class=. if S2 == -1 | S2==-2

*Social class dummies
gen social_class_cat = social_class
tabulate social_class_cat, generate(social_class_cat)
drop social_class_cat1
list social_class_cat2 social_class_cat3 social_class_cat4 social_class_cat5

*Has a job (self-employed, salaried work in a private or in a state company or temporarily out of work)
gen employed=(S18_A>=1 & S18_A<=4)

*Own house (yes)
gen own_house=(S20_B==1)
replace own_house=. if S20_B==-5

*Internet connection at home (yes)
gen internet=(S20_J==1)
replace internet=. if S20_J==-2

*Has Sewage system (yes)
gen sewage=(S20_G==1)
replace sewage=. if S20_G==-2

*Receives government transfer
gen subsidy=(S6>=1 & S6<=3)
replace subsidy=. if S6==-5

******************************************************
*B. Indicators

*1. Interpersonal trust (one can trust most people)
gen t_people=(P9STGBS==1)
replace t_people=. if P9STGBS==-5

*2. Confidence in institutions (a lot or some confidence)

*Police
gen t_police=(P13STGBS_B>=1 & P13STGBS_B<=2)
replace t_police=. if P13STGBS_B==-1 | P13STGBS_B==-2

*National Congress / Parliament
gen t_parliament=(P13ST_D>=1 & P13ST_D<=2)
replace t_parliament=. if P13ST_D==-1 | P13ST_D==-2

*Government
gen t_government=(P13ST_E>=1 & P13ST_E<=2)
replace t_government=. if P13ST_E==-1 | P13ST_E==-2

*Judiciary
gen t_courts=(P13ST_F>=1 & P13ST_F<=2)
replace t_courts=. if P13ST_F==-1 | P13ST_F==-2

*National Electoral Institution
gen t_elections=(P13ST_H>=1 & P13ST_H<=2)
replace t_elections=. if P13ST_H==-1 | P13ST_H==-2

*3. Interested in politics (very and fairly interested)
gen int_politics=(P40STGBS>=1 & P40STGBS<=2)
replace int_politics=. if P40STGBS==-1 | P40STGBS==-2

*3b. Political spectrum (0-10, left to right)  Self-positioning in Left- Right scale
gen political_spectrum=(P16ST)
replace political_spectrum=. if P16ST==-1 | P16ST==-2 | P16ST==97

gen left_wing=(political_spectrum<=5)
replace left_wing=. if political_spectrum==.

*4. Freedom of political participation is guaranteed: fully or somewhat
gen free_join=(P41ST_A>=1 & P41ST_A<=2)
replace free_join=. if P41ST_A==-5

*5. Freedom of expression is guaranteed: fully or somewhat
gen free_speak=(P41ST_H>=1 & P41ST_H<=2)
replace free_speak=. if P41ST_H==-5

*6. Victim of a crime in the last 12 months (you, relative or both)
gen victim_crime=(P58ST>=1 & P58ST<=3)
replace victim_crime=. if P58ST==-1 | P58ST==-2

*7. Food insecure: gone without enough food to eat in the last 12 months (sometimes or often)
gen enough_food=(S3>=3 & S3<=4)
replace enough_food=. if S3==-1 | S3==-2

*8. Able to save some money (yes)
gen save_money=(S5==1)
replace save_money=. if S5==-1 | S5==-2

*9. Life satisfaction (very and quite satisfied)
gen life_satisfaction=(P1ST>=1 & P1ST<=2)
replace life_satisfaction=. if P1ST==-5

* Civic participation

*10. Work for a problem that affects you or your community (Frequently and very Frequently)
gen civic_part=(P44ST_B>=1 & P44ST_B<=2)
replace civic_part=. if P44ST_B==-1 | P44ST_B==-2 

*11. Sign a petition (have ever done)
gen petition=(P45ST_A==1)
replace petition=. if P45ST_A==-5

*12. Take part in authorized demonstrations (have ever done)
gen demons=(P45S_B==1)
replace demons=. if P45S_B==-5

* C. Gender indicators

* Men have considerable advantage over Women when starting a business (Agree and Strongly agree)
gen women_1=(P30INN_D==1 | P30INN_D==2)
replace women_1=. if P30INN_D==-5

* I prefer to buy products produced by women than products produced by men (Agree and Strongly agree)
gen women_2=(P30INN_E==1 | P30INN_E==2)
replace women_2=. if P30INN_E==-5

* It is better that women concentrate at home and Man at work (Agree and Strongly agree)
gen women_3=(P37STCS_C==1 | P37STCS_C==2)
replace women_3=. if P37STCS_C==-5

* Men are better political leaders than women (Agree and Strongly agree)
gen women_4=(P37WVSSTCS_D==1 | P37WVSSTCS_D==2)
replace women_4=. if P37WVSSTCS_D==-5

* If the woman earns more that man is almost certainly she will have trouble (Agree and Strongly agree)
gen women_5=(P37STCS_E==1 | P37STCS_E==2)
replace women_5=. if P37STCS_E==-5

* When Jobs are scarce men should have more right than women to have a job (Agree and Strongly agree)
gen women_6=(P37WVSCS_G==1 | P37WVSCS_G==2)
replace women_6=. if P37WVSCS_G==-5

* Composite variable for gender biases
gen gender_perc=(women_3*0.25+women_4*0.25+women_5*0.25+women_6*0.25)

* Perform PCA on the gender variables
pca women_3 women_4 women_5 women_6

* Scree plot of eigenvalues after PCA (elbow method)
screeplot, ci mean

* Generate the first principal component (I keep only the first component since it's the only one with eigenvalue greater than 1, and confirmed by the elbow method)
predict pc1

* Normalize the first principal component to range from 0 to 1
egen pc1_min = min(pc1)
egen pc1_max = max(pc1)
gen composite_gender_score = (pc1 - pc1_min) / (pc1_max - pc1_min)

* Drop intermediate variables
drop pc1_min pc1_max

*** Simulated gender score ***

* Calculate statistics for composite_gender_score
summarize composite_gender_score
local mean = r(mean)
local max = r(max)
local min = r(min)

* Generate the new score centered around 0.1
gen new_score1 = (composite_gender_score - `r(mean)') / (`r(max)' - `r(min)') + 0.1

* Cap values to stay between 0 and 1
replace new_score1 = max(0, min(new_score1, 1)) if !missing(new_score1)

* Check the new distribution
sum new_score1
histogram new_score1, bins(5) normal

hist composite_gender_score, bins(5) normal

* Generate alternative gender score adding up the values of the gender variables
gen alt_gender_score = women_3 + women_4 + women_5 + women_6

* Generate dummy for high levels of machismo (i.e., when alt_gender_score>=2)
gen high_gender_score = (alt_gender_score>=2)
replace high_gender_score=. if alt_gender_score==.

save 		"$dataout/Latinobarometro_2023.dta", replace